@@ -4,6 +4,8 @@ from __future__ import unicode_literals
 
 
 EXTENSIONS = {
+    'adoc': {'text', 'asciidoc'},
+    'asciidoc': {'text', 'asciidoc'},
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
     'bash': {'text', 'shell', 'bash'},
@@ -14,6 +16,9 @@ EXTENSIONS = {
     'cc': {'text', 'c++'},
     'cu': {'text', 'cuda'},
     'cfg': {'text'},
+    'clj': {'text', 'clojure'},
+    'cljc': {'text', 'clojure'},
+    'cljs': {'text', 'clojure', 'clojurescript'},
     'cmake': {'text', 'cmake'},
     'cnf': {'text'},
     'coffee': {'text', 'coffee'},
@@ -21,6 +26,7 @@ EXTENSIONS = {
     'cpp': {'text', 'c++'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
+    'csh': {'text', 'shell', 'csh'},
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
@@ -29,6 +35,7 @@ EXTENSIONS = {
     'def': {'text', 'def'},
     'dtd': {'text', 'dtd'},
     'ear': {'binary', 'zip', 'jar'},
+    'edn': {'text', 'clojure', 'edn'},
     'ejs': {'text', 'ejs'},
     'eot': {'binary', 'eot'},
     'eps': {'binary', 'eps'},
@@ -42,6 +49,7 @@ EXTENSIONS = {
     'go': {'text', 'go'},
     'gotmpl': {'text', 'gotmpl'},
     'gpx': {'text', 'gpx', 'xml'},
+    'graphql': {'text', 'graphql'},
     'gradle': {'text', 'groovy'},
     'groovy': {'text', 'groovy'},
     'gyb': {'text', 'gyb'},
@@ -86,6 +94,8 @@ EXTENSIONS = {
     'md': {'text', 'markdown'},
     'mib': {'text', 'mib'},
     'mk': {'text', 'makefile'},
+    'ml': {'text', 'ocaml'},
+    'mli': {'text', 'ocaml'},
     'mm': {'text', 'c++', 'objective-c++'},
     'modulemap': {'text', 'modulemap'},
     'ngdoc': {'text', 'ngdoc'},
@@ -188,6 +198,7 @@ NAMES = {
     '.bash_profile': EXTENSIONS['bash'],
     '.bowerrc': EXTENSIONS['json'] | {'bowerrc'},
     '.coveragerc': EXTENSIONS['ini'] | {'coveragerc'},
+    '.cshrc': EXTENSIONS['csh'],
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
     '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
